@@ -411,6 +411,28 @@ class Game(GameNode):
         visitor.end_game()
         return visitor.result()
 
+    @classmethod
+    def from_board(cls, board):
+        """Creates a game from the move stack of a :class:`~chess.Board()`."""
+        # Undo all moves.
+        switchyard = collections.deque()
+        while board.move_stack:
+            switchyard.append(board.pop())
+
+        # Setup initial position.
+        game = cls()
+        game.setup(board)
+        node = game
+
+        # Replay all moves.
+        while switchyard:
+            move = switchyard.pop()
+            node = node.add_variation(move)
+            board.push(move)
+
+        game.headers["Result"] = board.result()
+        return game
+
 
 class BaseVisitor(object):
     """
@@ -768,7 +790,11 @@ def read_game(handle, Visitor=GameModelCreator):
         line = handle.readline()
 
     # Movetext parser state.
-    board_stack = collections.deque([dummy_game.board()])
+    try:
+        board_stack = collections.deque([dummy_game.board()])
+    except ValueError as error:
+        visitor.handle_error(error)
+        board_stack = collections.deque([chess.Board()])
 
     # Parse movetext.
     while line:
